==> 1.2.0.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/relatorios/utilitarios/RelatorioPassagensAGRBean.java <==
package com.rjconsultores.ventaboletos.relatorios.utilitarios;

public class RelatorioPassagensAGRBean {
	
	private String numeroBilhete;
	private String razaoSocial;
	private String cnpj;
	private String numeroPassaporte;
	private String tipoDescontoBenefício;
	
	private String nomePassageiro;
	private String numeroIdentidade;
	private String orgaoExpedidor;
	private String cpfPassageiro; 
	private String numeroPoltrona;
	private String dataViagem;
	private String mesViagem;
	private String horaViagem;
	
	private String numeroLinha;
	private String denominacaoLinha;
	private String localOrigem;
	private String localDestino;
	private String valorPassagem; 
	private String chaveAcessoBPE;
	private String imagemBPE;
	private String naturezaServico;
	
	public String getNumeroBilhete() {
		return numeroBilhete;
	}
	public void setNumeroBilhete(String numeroBilhete) {
		this.numeroBilhete = numeroBilhete;
	}
	public String getRazaoSocial() {
		return razaoSocial;
	}
	public void setRazaoSocial(String razaoSocial) {
		this.razaoSocial = razaoSocial;
	}
	public String getCnpj() {
		return cnpj;
	}
	public void setCnpj(String cnpj) {
		this.cnpj = cnpj;
	}
	public String getNumeroPassaporte() {
		return numeroPassaporte;
	}
	public void setNumeroPassaporte(String numeroPassaporte) {
		this.numeroPassaporte = numeroPassaporte;
	}
	public String getTipoDescontoBenefício() {
		return tipoDescontoBenefício;
	}
	public void setTipoDescontoBenefício(String tipoDescontoBenefício) {
		this.tipoDescontoBenefício = tipoDescontoBenefício;
	}
	public String getNomePassageiro() {
		return nomePassageiro;
	}
	public void setNomePassageiro(String nomePassageiro) {
		this.nomePassageiro = nomePassageiro;
	}
	public String getNumeroIdentidade() {
		return numeroIdentidade;
	}
	public void setNumeroIdentidade(String numeroIdentidade) {
		this.numeroIdentidade = numeroIdentidade;
	}
	public String getOrgaoExpedidor() {
		return orgaoExpedidor;
	}
	public void setOrgaoExpedidor(String orgaoExpedidor) {
		this.orgaoExpedidor = orgaoExpedidor;
	}
	public String getCpfPassageiro() {
		return cpfPassageiro;
	}
	public void setCpfPassageiro(String cpfPassageiro) {
		this.cpfPassageiro = cpfPassageiro;
	}
	public String getNumeroPoltrona() {
		return numeroPoltrona;
	}
	public void setNumeroPoltrona(String numeroPoltrona) {
		this.numeroPoltrona = numeroPoltrona;
	}
	public String getDataViagem() {
		return dataViagem;
	}
	public void setDataViagem(String dataViagem) {
		this.dataViagem = dataViagem;
	}
	public String getMesViagem() {
		return mesViagem;
	}
	public void setMesViagem(String mesViagem) {
		this.mesViagem = mesViagem;
	}
	public String getHoraViagem() {
		return horaViagem;
	}
	public void setHoraViagem(String horaViagem) {
		this.horaViagem = horaViagem;
	}
	public String getNumeroLinha() {
		return numeroLinha;
	}
	public void setNumeroLinha(String numeroLinha) {
		this.numeroLinha = numeroLinha;
	}
	public String getDenominacaoLinha() {
		return denominacaoLinha;
	}
	public void setDenominacaoLinha(String denominacaoLinha) {
		this.denominacaoLinha = denominacaoLinha;
	}
	public String getLocalOrigem() {
		return localOrigem;
	}
	public void setLocalOrigem(String localOrigem) {
		this.localOrigem = localOrigem;
	}
	public String getLocalDestino() {
		return localDestino;
	}
	public void setLocalDestino(String localDestino) {
		this.localDestino = localDestino;
	}
	public String getValorPassagem() {
		return valorPassagem;
	}
	public void setValorPassagem(String valorPassagem) {
		this.valorPassagem = valorPassagem;
	}
	public String getChaveAcessoBPE() {
		return chaveAcessoBPE;
	}
	public void setChaveAcessoBPE(String chaveAcessoBPE) {
		this.chaveAcessoBPE = chaveAcessoBPE;
	}
	public String getImagemBPE() {
		return imagemBPE;
	}
	public void setImagemBPE(String imagemBPE) {
		this.imagemBPE = imagemBPE;
	}
	public String getNaturezaServico() {
		return naturezaServico;
	}
	public void setNaturezaServico(String naturezaServico) {
		this.naturezaServico = naturezaServico;
	}
	
}

==> 1.152.0.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/relatorios/utilitarios/RelatorioPassagensAGRBean.java <==
package com.rjconsultores.ventaboletos.relatorios.utilitarios;

public class RelatorioPassagensAGRBean {
	
	private String numeroBilhete;
	private String razaoSocial;
	private String cnpj;
	private String numeroPassaporte;
	private String tipoDescontoBeneficio;
	
	private String nomePassageiro;
	private String numeroIdentidade;
	private String orgaoExpedidor;
	private String cpfPassageiro; 
	private String numeroPoltrona;
	private String dataViagem;
	private String mesViagem;
	private String horaViagem;
	
	private String numeroLinha;
	private String denominacaoLinha;
	private String localOrigem;
	private String localDestino;
	private String valorPassagem; 
	private String chaveAcessoBPE;
	private String imagemBPE;
	private String naturezaServico;
	
	public String getNumeroBilhete() {
		return numeroBilhete;
	}
	public void setNumeroBilhete(String numeroBilhete) {
		this.numeroBilhete = numeroBilhete;
	}
	public String getRazaoSocial() {
		return razaoSocial;
	}
	public void setRazaoSocial(String razaoSocial) {
		this.razaoSocial = razaoSocial;
	}
	public String getCnpj() {
		return cnpj;
	}
	public void setCnpj(String cnpj) {
		this.cnpj = cnpj;
	}
	public String getNumeroPassaporte() {
		return numeroPassaporte;
	}
	public void setNumeroPassaporte(String numeroPassaporte) {
		this.numeroPassaporte = numeroPassaporte;
	}
	public String getTipoDescontoBeneficio() {
		return tipoDescontoBeneficio;
	}
	public void setTipoDescontoBeneficio(String tipoDescontoBeneficio) {
		this.tipoDescontoBeneficio = tipoDescontoBeneficio;
	}
	public String getNomePassageiro() {
		return nomePassageiro;
	}
	public void setNomePassageiro(String nomePassageiro) {
		this.nomePassageiro = nomePassageiro;
	}
	public String getNumeroIdentidade() {
		return numeroIdentidade;
	}
	public void setNumeroIdentidade(String numeroIdentidade) {
		this.numeroIdentidade = numeroIdentidade;
	}
	public String getOrgaoExpedidor() {
		return orgaoExpedidor;
	}
	public void setOrgaoExpedidor(String orgaoExpedidor) {
		this.orgaoExpedidor = orgaoExpedidor;
	}
	public String getCpfPassageiro() {
		return cpfPassageiro;
	}
	public void setCpfPassageiro(String cpfPassageiro) {
		this.cpfPassageiro = cpfPassageiro;
	}
	public String getNumeroPoltrona() {
		return numeroPoltrona;
	}
	public void setNumeroPoltrona(String numeroPoltrona) {
		this.numeroPoltrona = numeroPoltrona;
	}
	public String getDataViagem() {
		return dataViagem;
	}
	public void setDataViagem(String dataViagem) {
		this.dataViagem = dataViagem;
	}
	public String getMesViagem() {
		return mesViagem;
	}
	public void setMesViagem(String mesViagem) {
		this.mesViagem = mesViagem;
	}
	public String getHoraViagem() {
		return horaViagem;
	}
	public void setHoraViagem(String horaViagem) {
		this.horaViagem = horaViagem;
	}
	public String getNumeroLinha() {
		return numeroLinha;
	}
	public void setNumeroLinha(String numeroLinha) {
		this.numeroLinha = numeroLinha;
	}
	public String getDenominacaoLinha() {
		return denominacaoLinha;
	}
	public void setDenominacaoLinha(String denominacaoLinha) {
		this.denominacaoLinha = denominacaoLinha;
	}
	public String getLocalOrigem() {
		return localOrigem;
	}
	public void setLocalOrigem(String localOrigem) {
		this.localOrigem = localOrigem;
	}
	public String getLocalDestino() {
		return localDestino;
	}
	public void setLocalDestino(String localDestino) {
		this.localDestino = localDestino;
	}
	public String getValorPassagem() {
		return valorPassagem;
	}
	public void setValorPassagem(String valorPassagem) {
		this.valorPassagem = valorPassagem;
	}
	public String getChaveAcessoBPE() {
		return chaveAcessoBPE;
	}
	public void setChaveAcessoBPE(String chaveAcessoBPE) {
		this.chaveAcessoBPE = chaveAcessoBPE;
	}
	public String getImagemBPE() {
		return imagemBPE;
	}
	public void setImagemBPE(String imagemBPE) {
		this.imagemBPE = imagemBPE;
	}
	public String getNaturezaServico() {
		return naturezaServico;
	}
	public void setNaturezaServico(String naturezaServico) {
		this.naturezaServico = naturezaServico;
	}
	
}
